<?php

/*
Plugin Name: Plugin Template
Plugin URI: http://wordpress.org/#
Description: The Plugin Template WordPress plugin provides a convenient starting place for WordPress plugin development.
Author: Alex Mansfield
Version: 1.0
Author URI: http://alexmansfield.com/
*/


/******************** Plugin Template Setup *********************/

// Import built-in javascript (in this case: jquery)
wp_enqueue_script('jquery'); // this is only necessary if you're using jquery


// Import custom javascript (in this case: the js/script.js file in the plugin folder)
wp_register_script('plugintemplate_js', plugins_url('js/script.js', __FILE__));// this is only necessary if you're using your own javascript file
wp_enqueue_script('plugintemplate_js'); // this is only necessary if you're using your own javascript file


// Import custom stylesheets (in this case: the css/style.css file in the plugin folder)
wp_register_style('plugintemplate_css', plugins_url('css/style.css', __FILE__));// this is only necessary if you're using your own javascript file
wp_enqueue_style('plugintemplate_css'); // this is only necessary if you're using your own javascript file


// Add shortcodes
add_shortcode('plugintemplate', 'plugintemplate_shortcode');


/******************** Plugin Template Functions *****************/

// Display shortcode result
function plugintemplate_shortcode($array) {
	$options = get_option('plugintemplate_options');
	
	extract(shortcode_atts(array(
		'location' => 'http://localhost',
		'transition_effect' => $options['transition_effect'],
		'delay' => $options['delay'],
		'transition_time' => $options['transition_time'],
		'height' => $options['height'],
		'width' => $options['width']),
		$array));
	switch($options['float']){
		case 'Left':
			$float = 'class="alignleft"';
			break;
		case 'Right':
			$float = 'class="alignright"';
			break;
		default:
			$float = '';
			break;
	}

	if($options['image']){
		$url = $options['url'];
	}else{
		$url = plugins_url('img/test.jpg', __FILE__);
	}

	echo '<img id="plugin-template" ' . $float . ' src="' . $url . '" />' . "\n";
}


/******************** Options Page Functions ********************/

// Add hooks and actions
add_action('admin_init', 'plugintemplate_register_settings' );
add_action('admin_menu', 'am_add_options_page');

// Add options page to settings menu
function am_add_options_page() {
	add_options_page('Plugin Template Settings', 'Plugin Template', 'administrator', __FILE__, 'plugintemplate_display_options');
}


// Register the settings. Add the settings section and settings fields
function plugintemplate_register_settings(){
	register_setting('plugintemplate_options', 'plugintemplate_options');
	add_settings_section('main_section', 'Default Settings', 'plugintemplate_main_section', __FILE__);
		add_settings_field('float',					'Float Image',			'plugintemplate_radio',		__FILE__,	'main_section',	$args = array('id' => 'float', 'options' => 'Left,Right,None'));
		add_settings_field('image',					'Custom Image',		'plugintemplate_checkbox',	__FILE__,	'main_section',	$args = array('id' => 'image', 'description' => 'Use a custom image, rather than the test image provided by the plugin'));
		add_settings_field('ulr',						'Custom Image URL',	'plugintemplate_textbox',		__FILE__,	'main_section',	$args = array('id' => 'url', 'description' => 'If "Custom Image" is selected above, place the image URL here.'));
}


// Display the admin options page
function plugintemplate_display_options() {
	?>
	<div class="wrap">
		<?php screen_icon(); ?>
		<h2>Plugin Template Options</h2>
		<form action="options.php" method="post">
			<?php settings_fields('plugintemplate_options'); ?>
			<?php do_settings_sections(__FILE__); ?>
			<p class="submit">
				<input name="Submit" type="submit" class="button-primary" value="<?php esc_attr_e('Save Changes'); ?>" />
			</p>
		</form>
	</div>
	<?php
}


/******************** callback functions ********************/

// HTML for main_section
function  plugintemplate_main_section() {
	?>
	<p>This plugin is only a starting point. It contains all the building blocks you need to write your own plugin. <br />
	To show just how these blocks work, this plugin displays a sample image via the [plugintemplatecode] shortcode. <br />
	Try it in a post and test the changes these theme options make.</p>
	<?php 
}


// Textboxes
function plugintemplate_textbox($args) {
	$options = get_option('plugintemplate_options');
	echo '<input id="' . $args['id'] . '" name="plugintemplate_options[' . $args['id'] . ']" size="40" type="text" value="' . $options[$args['id']] . '" class="regular-text" />' . "\n";
	if($args['description']){
		echo '<span class="description">' . $args['description'] . '</span>';
	}
}


// Textareas
function plugintemplate_textarea($args) {
	$options = get_option('plugintemplate_options');
	if($args['description']){
		echo '<span class="description">' . $args['description'] . '</span><br />' . "\n";
	}
	echo '<textarea id="' . $args['id'] . '" name="plugintemplate_options[' . $args['id'] . ']" rows="7" cols="50" type="textarea">' . $options[$args['id']] . '</textarea>' . "\n";
}


// Dropdown lists (selects)
function  plugintemplate_dropdown($args) {
	$options = get_option('plugintemplate_options');
	$choices = explode(',', $args['options']);
	echo '<select id="' . $args['id'] . '" name="plugintemplate_options[' . $args['id'] . ']">' . "\n";
	foreach($choices as $choice) {
		$selected = ($options[$args['id']]==$choice) ? 'selected="selected"' : '';
		echo '<option value="' . $choice . '" ' . $selected . '>' . $choice . '</option>' . "\n";
	}
	echo '</select>' . "\n";
	if($args['description']){
		echo '<span class="description">' . $args['description'] . '</span>' . "\n";
	}
}


// Radio buttons
function plugintemplate_radio($args) {
	$options = get_option('plugintemplate_options');
	$choices = explode(',', $args['options']);
	if($args['description']){
		echo '<span class="description">' . $args['description'] . '</span><br />' . "\n";
	}
	foreach($choices as $choice) {
		$checked = ($options[$args['id']]==$choice) ? ' checked="checked" ' : '';
		echo '<label><input ' . $checked . ' value="' . $choice . '" name="plugintemplate_options[' . $args['id'] . ']" type="radio" /> ' . $choice . '</label><br />' . "\n";
	}
}


// Checkboxes
function plugintemplate_checkbox($args) {
	$options = get_option('plugintemplate_options');
	if($options[$args['id']]) {
		$checked = ' checked="checked" ';
	}
	echo '<label><input ' . $checked . ' id="' . $args['id'] . '" name="plugintemplate_options[' . $args['id'] . ']" type="checkbox" /> ' . $args['description'] . '</label>' . "\n";
}


// Passwords
function plugintemplate_password($args) {
	$options = get_option('plugintemplate_options');
	echo '<input id="' . $args['id'] . '" name="plugintemplate_options[' . $args['id'] . ']" size="40" type="password" value="' . $options[$args['id']] . '" class="regular-text" />' . "\n";
	if($args['description']){
		echo '<span class="description">' . $args['description'] . '</span>';
	}
}

?>